@@ -1,14 +1,19 @@
-from py5paisa import FivePaisaClient
+#from py5paisa import FivePaisaClient
 from py5paisa.order import Order,Bo_co_order
 import json
 
 
 class strategies:
 
-    def __init__(self,user=None,passw=None,dob=None,cred=None):
-        self.Client=FivePaisaClient(email=user, passwd=passw, dob=dob,cred=cred)
-        self.Client.login()
-        
+    def __init__(self, user=None, passw=None, dob=None, cred=None, request_token=None):
+        if request_token is None:
+            self.Client = FivePaisaClient(email=user, passwd=passw, dob=dob, cred=cred)
+            self.Client.login()
+        else:
+            self.Client = FivePaisaClient(cred=cred)
+            self.Client.get_access_token(request_token)
+
+    email = user, passwd = passw, dob = dob,
     def get_scripcode(self,symbol,strike,expiry,opt):
         month={
             "01":'JAN',
